Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(770)

Unified Diff: content/public/common/service_manager_connection.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/service_info.h ('k') | content/public/gpu/content_gpu_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/service_manager_connection.h
diff --git a/content/public/common/service_manager_connection.h b/content/public/common/service_manager_connection.h
index c756ae6cd40b22003a7bb7fafa605f292fed28c1..23b8f1a6c3f4b241cd734c7ba236e75b03de0d33 100644
--- a/content/public/common/service_manager_connection.h
+++ b/content/public/common/service_manager_connection.h
@@ -14,7 +14,7 @@
#include "services/service_manager/public/cpp/identity.h"
#include "services/service_manager/public/interfaces/service.mojom.h"
-namespace shell {
+namespace service_manager {
class Connection;
class Connector;
class InterfaceProvider;
@@ -28,7 +28,8 @@ class ConnectionFilter;
// Encapsulates a connection to a //services/service_manager.
// Access a global instance on the thread the ServiceContext was bound by
// calling Holder::Get().
// Clients can add shell::Service implementations whose exposed interfaces
// will be exposed to inbound connections to this object's Service.
// Alternatively clients can define named services that will be constructed when
// requests for those service names are received.
@@ -37,7 +38,7 @@ class ConnectionFilter;
class CONTENT_EXPORT ServiceManagerConnection {
public:
using ServiceRequestHandler =
- base::Callback<void(shell::mojom::ServiceRequest)>;
+ base::Callback<void(service_manager::mojom::ServiceRequest)>;
using Factory =
base::Callback<std::unique_ptr<ServiceManagerConnection>(void)>;
@@ -65,7 +66,7 @@ class CONTENT_EXPORT ServiceManagerConnection {
// its interfaces and accept new connections on |io_task_runner| only. Note
// that no incoming connections are accepted until Start() is called.
static std::unique_ptr<ServiceManagerConnection> Create(
- shell::mojom::ServiceRequest request,
+ service_manager::mojom::ServiceRequest request,
scoped_refptr<base::SequencedTaskRunner> io_task_runner);
// Begins accepting incoming connections. Connection filters MUST be added
@@ -77,14 +78,16 @@ class CONTENT_EXPORT ServiceManagerConnection {
// request from the shell.
virtual void SetInitializeHandler(const base::Closure& handler) = 0;
// Returns the shell::Connector received via this connection's Service
// implementation. Use this to initiate connections as this object's Identity.
- virtual shell::Connector* GetConnector() = 0;
+ virtual service_manager::Connector* GetConnector() = 0;
// Returns this connection's identity with the Service Manager. Connections
// initiated via the shell::Connector returned by GetConnector() will use
// this.
- virtual const shell::Identity& GetIdentity() const = 0;
+ virtual const service_manager::Identity& GetIdentity() const = 0;
// Sets a closure that is called when the connection is lost. Note that
// connection may already have been closed, in which case |closure| will be
@@ -104,8 +107,8 @@ class CONTENT_EXPORT ServiceManagerConnection {
// TODO(rockot): Remove this. It's a temporary solution to avoid porting all
// relevant code to ConnectionFilters at once.
virtual void SetupInterfaceRequestProxies(
- shell::InterfaceRegistry* registry,
- shell::InterfaceProvider* provider) = 0;
+ service_manager::InterfaceRegistry* registry,
+ service_manager::InterfaceProvider* provider) = 0;
static const int kInvalidConnectionFilterId = 0;
« no previous file with comments | « content/public/common/service_info.h ('k') | content/public/gpu/content_gpu_client.h » ('j') | no next file with comments »
@@ -28,7 +28,8 @@ class ConnectionFilter;
// Access a global instance on the thread the ServiceContext was bound by
// calling Holder::Get().
-// Clients can add shell::Service implementations whose exposed interfaces
+// Clients can add service_manager::Service implementations whose exposed
+// interfaces
// will be exposed to inbound connections to this object's Service.
// Alternatively clients can define named services that will be constructed when
@@ -77,14 +78,16 @@ class CONTENT_EXPORT ServiceManagerConnection {
// request from the shell.
virtual void SetInitializeHandler(const base::Closure& handler) = 0;
- // Returns the shell::Connector received via this connection's Service
+ // Returns the service_manager::Connector received via this connection's
+ // Service
// implementation. Use this to initiate connections as this object's Identity.
@@ -77,14 +78,16 @@ class CONTENT_EXPORT ServiceManagerConnection {
// Returns this connection's identity with the Service Manager. Connections
- // initiated via the shell::Connector returned by GetConnector() will use
+ // initiated via the service_manager::Connector returned by GetConnector()
+ // will use
// this.

Powered by Google App Engine
This is Rietveld 408576698